/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
*   This file is part of the Java Expressions Library (JEL).
*   For more information about JEL visit : http://fti.dn.ua/JEL/
*
*   Copyright (C) 1998, 1999, 2000, 2001, 2003, 2006, 2007, 2009 Konstantin L. Metlov
*
*   This program is free software: you can redistribute it and/or modify
*   it under the terms of the GNU General Public License as published by
*   the Free Software Foundation, either version 3 of the License, or
*   (at your option) any later version.
*
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*
*   You should have received a copy of the GNU General Public License
*   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package gnu.jel.tests;

public class StringObject implements gnu.jel.reflect.String {
  String val;

  public StringObject(String val) {
    this.val=val;
  };

  public int aMethod() {
    return 1;
  };

  public boolean equals(Object obj) {
    if (!(obj instanceof StringObject)) return false;
    return val.equals(((StringObject)obj).val);
  };

  public int hashCode() {
    return val.hashCode();
  };

  public String toString() {
    return val;
  };
};
